@@ -15,7 +15,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KGAPI2_CALENDAR_FREEBUSYQUERYJOB_H
@@ -34,6 +34,16 @@ class KGAPICALENDAR_EXPORT FreeBusyQueryJob : public KGAPI2::FetchJob
     Q_OBJECT
 public:
     struct BusyRange {
+        BusyRange() {};
+        BusyRange(const QDateTime &busyStart, const QDateTime &busyEnd)
+            : busyStart(busyStart), busyEnd(busyEnd)
+        {}
+
+        bool operator==(const BusyRange &other) const
+        {
+            return busyStart == other.busyStart && busyEnd == other.busyEnd;
+        }
+
         QDateTime busyStart;
         QDateTime busyEnd;
     };
