@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_CONTACTMODIFYJOB_H
@@ -65,7 +65,7 @@ class KGAPICONTACTS_EXPORT ContactModifyJob : public  KGAPI2::ModifyJob
     /**
      * @brief Destructor
      */
-    virtual ~ContactModifyJob();
+    ~ContactModifyJob() override;
 
   protected:
 
