@@ -27,6 +27,7 @@
 #include "kgapicore_export.h"
 
 #include <QObject>
+#include <QUrl>
 
 class QNetworkAccessManager;
 class QNetworkReply;
@@ -40,12 +41,13 @@ namespace KGAPI2 {
  *
  * Usual workflow of Job subclasses is to reimplement Job::start,
  * Job::dispatchRequest and Job::handleReply, then enqueue a QNetworkRequest using
- * Job::enqueueRequest. The request will automatically be scheduled in a queue
- * and dispatched by calling Job::dispatchRequest implementation. When a reply
- * is received, the Job will automatically perform error handling and if there
- * is no error, the reply is passed to implementation of Job::handleReply.
+ * Job::enqueueRequest. Authorization headers and standard query parameters will be
+ * set by Job class. The request will automatically be scheduled in a queue and
+ * dispatched by calling Job::dispatchRequest implementation. When a reply is received,
+ * the Job will automatically perform error handling and if there is no error, the
+ * reply is passed to implementation of Job::handleReply.
  *
- * Job is automatically when program enters an event loop.
+ * Job is automatically started when program enters an event loop.
  *
  * @author Daniel Vrátil <dvratil@redhat.com>
  * @since 2.0
@@ -72,7 +74,7 @@ class KGAPICORE_EXPORT Job : public QObject
      * @brief Whether the job is running
      *
      * This property indicates whether the job is running or not. The value is
-     * set to @p true when the job is started (see Job::start) and back to 
+     * set to @p true when the job is started (see Job::start) and back to
      * @p false right before Job::finished is emitted.
      *
      * @see Job::isRunning, Job::finished
@@ -96,6 +98,11 @@ class KGAPICORE_EXPORT Job : public QObject
      */
     explicit Job(const AccountPtr &account, QObject* parent = nullptr);
 
+    struct StandardParams {
+        static const QString PrettyPrint;
+        static const QString Fields;
+    };
+
     /**
      * @brief Destructor
      */
@@ -178,6 +185,42 @@ class KGAPICORE_EXPORT Job : public QObject
      */
     AccountPtr account() const;
 
+    /**
+     * @brief Sets whether response will have indentations and line breaks.
+     *
+     * When this is false, it can reduce the response payload size,
+     * which might lead to better performance in some environments.
+     * Default is false.
+     *
+     * @param prettyPrint
+     */
+    void setPrettyPrint(bool prettyPrint);
+
+    /**
+     * @brief Returns prettyPrint query parameter.
+     *
+     * @return prettyPrint query parameter
+     */
+    bool prettyPrint() const;
+
+    /**
+     * @brief Set subset of fields to include in the response.
+     *
+     * Use for better performance.
+     *
+     * @param fields List of fields
+     */
+    void setFields(const QStringList &fields);
+
+    static QString buildSubfields(const QString &field, const QStringList &fields);
+
+    /**
+     * @brief Returns fields selector.
+     *
+     * @return List of fields
+     */
+    QStringList fields() const;
+
     /**
      * @brief Restarts this job
      *
@@ -186,7 +229,7 @@ class KGAPICORE_EXPORT Job : public QObject
      *
      * The job will throw away all results retrieved in previous run and retrieve
      * everything again.
-     * 
+     *
      * @see Job::aboutToStart
      */
     void restart();
@@ -313,6 +356,7 @@ class KGAPICORE_EXPORT Job : public QObject
      *
      * Subclasses should call this method to enqueue the @p request in main job
      * queue. The request is automatically dispatched, and reply is handled.
+     * Authorization headers and standars query parameters will be applied.
      *
      * @param request Request to enqueue
      * @param data Data to be send in body of the request
